#
# spec file for package cdio-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cdioutils 1
Name:           cdio-utils
Version:        2.1.0
Release:        7.5
Summary:        Utility programs making use of libcdio, a CD-ROM access library
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://savannah.gnu.org/projects/libcdio
Source0:        https://ftp.gnu.org/gnu/libcdio/libcdio-%{version}.tar.bz2
Source1:        https://ftp.gnu.org/gnu/libcdio/libcdio-%{version}.tar.bz2.sig
Source2:        libcdio.keyring
Source4:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  libcdio-devel
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libvcdinfo) >= 2.0
Provides:       libcdio-utils = %{version}
Obsoletes:      libcdio-utils < %{version}

%description
This package contains a number of utility programs that make use of
libcdio.

%prep
%setup -q -n libcdio-%{version}

%define buildir ${PWD}

%build
export VCDINFO_CFLAGS=-I%{_includedir}/libvcd
export VCDINFO_LIBS="-L%{_libdir} -lvcdinfo -L%{buildir}/lib/iso9660/.libs/ -liso9660 -L%{buildir}/lib/driver/.libs/ -lcdio"

VCDINFO_CFLAGS=-I%{_includedir}/libvcd VCDINFO_LIBS="-L%{_libdir} -lvcdinfo -L%{buildir}/lib/iso9660/.libs -liso9660 \
-L%{buildir}/lib/driver/.libs -lcdio" \
%configure \
	--disable-silent-rules \
	--disable-rpath \
	--disable-static \
	--disable-cxx \
	--enable-vcd-info=yes

VCDINFO_CFLAGS=-I%{_includedir}/libvcd VCDINFO_LIBS="-L%{_libdir} -lvcdinfo \
-L%{buildir}/lib/iso9660/.libs/ -liso9660 -L%{buildir}/lib/driver/.libs/ -lcdio" \
make %{?_smp_mflags}

%install
%make_install
#empty depdendency libs
rm -rf %{buildroot}%{_libdir} %{buildroot}%{_includedir} %{buildroot}%{_infodir}
%fdupes -s %{buildroot}%{_mandir}

%files -n cdio-utils
%doc AUTHORS NEWS.md README README.libcdio THANKS TODO
%license COPYING*
%{_bindir}/cd-*
%{_bindir}/cdda-*
%{_bindir}/iso-*
%{_bindir}/mmc-*
%{_mandir}/man?/*%{ext_man}

%changelog
* Mon Jun 11 2018 kbabioch@suse.com
- Update to version 2.0.0
  - Fixed several memory leaks
- Applied spec-cleaner
- Require newer vcdimager
* Tue Sep  5 2017 jengelh@inai.de
- Remove --with-pic (only useful for static libs) and compact
  - -enable-static=n.
- Change description to reflect the package content.
* Sun Sep  3 2017 astieger@suse.com
- update to 0.94:
  * CD-TEXT fixes and improvements
  * eject fixes
  * various bug fixes
* Tue Jun 16 2015 mpluskal@suse.com
- Add gpg signature
- Remove ppc obsoletes/provides as it affects unsupported releases
- Cleanup spec file with spec-cleaner
* Sat Jan 31 2015 p.drouand@gmail.com
- Update to version 0.93
  * Add cdio_free, iso9660_stat_free, and iso9660_xa_free functions.
  * Deprecate mmc_isrc_track_read_subchannel
  * Add mmc_get_track_isrc function.
  * Update OS versions we recognize
  * OSX, and MS Windows, ISO 9660 and other bug fixes
  * Remove Coverty scan warnins and errors
  * OS/2 driver performance update - KO Myung-Hun
- Bump so versions
  * libcdio14 to libcdio16
  * libiso9660-8 to libiso9660-10
- Update baselibs.conf
- Remove depreciated AUTHORS section
* Sun Feb 17 2013 reddwarf@opensuse.org
- Update to 0.90
  * CD-Text overhaul and API change (Leon Merten Lohse)
  * Works again (somewhat) on MinGW; tolerence for Microsoft's C compiler (Pete Batard)
  * UDF, Joliet and Rock-Ridge fixes (Pete Batard)
  * OSX fixes (Natalia Portillo and Robert William Fuller)
  * paranoia library removed as that is GPL 2-ish. This is now a separate project
  * file names in cue files are relative to the cue file rather than cwd.
  * Update mmc.h to include MMC-5 commands. (Or MMC-6 since it adds nothing new)
  * Add mmc_cmd2str() to show MMC command name. Show that in some errors
  * Add UDF reading to iso-read and iso-info via --udf or -U (Christophe Fergeau)
  * bug fixes, more tests, update documentation
* Fri May 18 2012 davejplater@gmail.com
- Created seperate linked package cdio-utils to prevent cycles.
* Sun Apr 15 2012 davejplater@gmail.com
- Update to 0.83.git from 14/04/2012 git head.
- libcdio-paranoia separated from libcdio due to license issues
  see bnc#756564
* Fri Apr  6 2012 davejplater@gmail.com
- Update to libcdio-0.83, removed need for libcdio-mini by adding
  linker library paths to sources in the spec file build section.
- Upstream changes:
  * Add retrieval SCSI sense reply from the most-recent MMC command.
  * Add exclusive read/write access for devices which is used for
  experimental writing/burning. Currently only on GNU/Linux and FreeBSD.
  * MMC bug fixes
  * FreeBSD drive list now shows empty drives.
  * Add ability to retrieve SCSI tuple for a name and/or fake one up for
  programs that wanto to cd-record compatible.
  * Tolerance for OS's without timezone in their struct tm (e.g. Solaris)
  added iso9660_set_{d,l}time_with_timezone
  * Add mmc_get_disk_erasable
  * Update MMC Feature Profile list, DVD Book types
  * Reduce range of seek in paranoia_seek to be int32_t
  * Remove some potential flaws found by Coverty's static analysis tool
  * Add ISRC track info to cd-info output.
  * Don't wrap-around volume adjustment for cdda-player.
  * Handle double-byte strings in CD-text
  * --no-header on cd-info omits copyright and warranty
* Sun Nov 13 2011 coolo@suse.com
- add libtool as buildrequire
* Sun Nov 13 2011 coolo@suse.com
- one less _service file for factory
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Tue Feb  8 2011 dimstar@opensuse.org
- Rename Shared Object package to libcdio12, conforming the
  libraries name.
- Adjust rpmlintrc to only ignore shared lib names of the -mini
  packages. This avoids missing shlib renames for the 'main'
  package.
* Sun Jan 30 2011 sagiben@gmail.com
- Updated to version 0.82
- Upstream changes :
  * Remove all uses of CDIO_MIN_DRIVER,
  CDIO_MAX_DRIVER, CDIO_MIN_DEVICE_DRIVER or CDIO_MAX_DEVICE_DRIVER.
  * FreeBSD get_media_changed fixes
  * MingGW/Msys compilation issues
  * Add OS/2 driver
  * Cross compilations fixes and uclinix is like GNU/Linux
  * Numerous other bug fixes
* Mon Apr 26 2010 ro@suse.de
- add build-ignore for libcdio-mini-devel
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Thu Aug  6 2009 sbrabec@suse.cz
- Updated to version 0.81:
  * license of manual now GFDL 1.2 or later
  * Nero image handling more complete.
  * ISRC query for image files.
  * Allow reading pregap of a track via get_track_pregap_lsn().
  * Fixes of iso9660 time setting/getting routines, making them
    reentrant.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Sep  9 2008 sbrabec@suse.cz
- Update Summary of *mini* packages (bnc#418304).
* Wed Jun 18 2008 schwab@suse.de
- Use autoreconf -i.
* Fri May 23 2008 hpj@suse.de
- Add libcdio-bnc394195-install-all-pc-files.patch (bnc#394195).
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Fri Apr 25 2008 sbrabec@suse.cz
- Updated to version 0.80:
  * Add option to log summary output in cd-paranoia
  * More string bounds checking to eliminate known string overflow
    conditions, Savannah#21910
  * add --mode="any" on cd-read which uses a mmc_read_sectors with
    read-type CDIO_MMC_READ_TYPE_ANY.
  * add --log-summary option to cd-paranoia. Unused option
  - -output-info (-i) removed
  * some small packaging bugs fixed
  * probably the last GPL v2 release; GPL v3 on the horizon.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb 27 2008 sbrabec@suse.cz
- Fixed more possible memory allocation buffer overflows
  (bnc#351127).
* Wed Jan  9 2008 sbrabec@suse.cz
- Fixed buffer overflows for long Joliet names (#351127).
* Wed Dec  5 2007 ro@suse.de
- provide main package name in library package for debuginfo
  for mini package
* Fri Nov 16 2007 sbrabec@suse.cz
- Removed unwanted NoSource preventing mirroring to Factory.
* Fri Nov  9 2007 crrodriguez@suse.de
- fix build with gcc43
- update to version 0.79
  * libcdio cdparanoia doing the wrong thing on a single-sector read. Savannah patch #5999.
  * Leds to an open file descriptor making it impossible of e.g.
  unmounting a CDROM containing the file. Savannah bug #21147.
  * bug #19221 (possibly): memory Leak opening an inaccessible device
  * more than 30 other bugfixes
- remove libtool archives with empty dependency_libs
- exclude static libraries
* Tue Aug  7 2007 sbrabec@suse.cz
- Fixed mini file list.
* Sun Aug  5 2007 coolo@suse.de
- adding versioned provides for upgrade
* Fri Jul 20 2007 sbrabec@suse.cz
- Updated to version 0.78.2:
  * Fixed bug in libcdio.so version numbering.
  * Added mmc-tool and mmc-close-tray.
  * libudf: can now read (extract) file data, at least for ICB
    strategy type 4.
  * libcdio is starting to get updated for UTF-8 support.
  * Fixes to eject.
  * Other fixes.
- Split package according to shared library packaging policy.
- Added script to convert libcdio.spec to libcdio-mini.spec and
  update library package names.
* Mon Mar 12 2007 sbrabec@suse.cz
- Fixed NoSrc and Provides of temporary package.
* Fri Oct  6 2006 sbrabec@suse.cz
- Updated to version 0.77:
  * Added object-oriented C++ wrapper.
  * Replaced libpopt with getopt in binaries.
  * Documented cd-paranoia.
  * Added cdio_eject_media_drive.
  * Added more generic read_sectors().
  * Some provision for handling Rock-Ridge device numbers.
  * Block read routines return success if asked to read 0 blocks.
  * Start UDF handling
  * Improved developer documentation.
  * Code improvements.
  * Bug fixes.
  * Small cdda-player improvements.
  * NRG checking parses file.
  * Revised and improved example programs.
  * Replaced all uses of strcat and strcpy with strncat and
    strncpy.
* Mon Jul  3 2006 max@suse.de
- Added gcc-c++ to neededforbuild.
* Fri Jun 30 2006 sbrabec@suse.cz
- Fixed cyclic dependencies in a correct way.
* Tue Jun 27 2006 sbrabec@suse.cz
- Use NoSource in libcdio-mini.
* Thu Jun 22 2006 sbrabec@suse.cz
- Simpler solution of cyclic dependencies.
* Tue Jan 31 2006 sbrabec@suse.cz
- Do not link with invalid rpath.
- Enabled parallel build.
- Fixed devel splitting.
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 sbrabec@suse.cz
- Fixed libiso9660.la circular dependency prevention trick.
* Wed Oct 26 2005 sbrabec@suse.cz
- Updated to version 0.76.
- Build as user.
* Fri Aug  5 2005 sbrabec@suse.cz
- Build with libcddb-1.2.1.
* Fri Jul 29 2005 sbrabec@suse.cz
- Updated to version 0.75.
* Mon May  9 2005 sbrabec@suse.cz
- Build with libcddb-1.0.2.
* Tue Apr 26 2005 sbrabec@suse.cz
- Updated to version 0.73.
* Fri Apr  1 2005 meissner@suse.de
- fixed gcc4 compile problem.
* Thu Feb  3 2005 sbrabec@suse.cz
- Updated to version 0.72.
* Mon Jan 31 2005 sbrabec@suse.cz
- Updated to version 0.72rc2.
* Mon Jan 24 2005 sbrabec@suse.cz
- Updated to version 0.71.
* Tue Nov  9 2004 sbrabec@suse.cz
- New SuSE package, version 0.70.
- Work-around of circular dependency on libcddb and vcdimager.
